@@ -1,3 +1,19 @@
+/*
+ * This file is part of gnome-terminal.
+ *
+ * Gnome-terminal is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * Gnome-terminal is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ */
 #include <config.h>
 #include <libintl.h>
 #include <gtk/gtk.h>
@@ -531,7 +547,7 @@ egg_cell_renderer_keys_start_editing (GtkCellRenderer      *cell,
 
   if (gdk_pointer_grab (widget->window, FALSE,
                         GDK_BUTTON_PRESS_MASK,
-                        FALSE, NULL,
+                        NULL, NULL,
                         gdk_event_get_time (event)) != GDK_GRAB_SUCCESS)
     {
       gdk_keyboard_ungrab (gdk_event_get_time (event));
